Module api

Module api 

This module defines the API that can be used for implementing plugins. NOTE: this API is NOT FFI-safe and is intended for use in the plugin AFTER the FFI layer. See plugin_interface::ffi for the FFI-safe types and traits.

Structs

CheckpointEpoch
PluginStateBackend
State backend for plugins.
PluginStateBackendFactory

Enums

PluginError

Statics

STREAMLING_COLUMN_NAME_OP

Traits

PreprocessorPlugin
Optional, non-FFI trait for the plugins to implement preprocessor support. Preprocessors transform the raw topology config string before parsing.
SideOutputPlugin
Trait for plugins to implement side output support. Side outputs observe data from all sources without modifying the pipeline. Unlike other plugin types, side outputs use direct FFI invocation (no channels). One instance is created per source via new(source_name, schema, options, metrics_recorder).
SinkPlugin
Optional, non-FFI trait for the plugins to implement sink support.
SourcePlugin
Optional, non-FFI trait for the plugins to implement source support.
SupportsGracefulShutdown
TransformPlugin
Optional, non-FFI trait for the plugins to implement transform support.