Module async

Module async 

Modules

PluginAsyncRuntime_trait
This module is generated by the #[sabi_trait] attribute on PluginAsyncRuntime

Structs

DirectTokioProxy
A special implementation of PluginAsyncRuntime that uses Tokio’s runtime directly. This means that a complete Tokio runtime is created and used by a plugin.
PluginAsyncRuntime_TO
The trait object for PluginAsyncRuntime.

Traits

PluginAsyncRuntime
Async runtime for performing asynchronous operations in the plugin. See [PluginTokioWrapper] on the host side for FFI-safe implementation.

Type Aliases

PluginAsyncRuntimeObj
PluginAsyncRuntime_CTO
A type alias for the const-constructible PluginAsyncRuntime_TO.