Module PluginAsyncRuntime_trait

Module PluginAsyncRuntime_trait 

This module is generated by the #[sabi_trait] attribute on PluginAsyncRuntime

Structs

PluginAsyncRuntime_Interface
A marker type describing the traits that are required when constructing PluginAsyncRuntime_TO,and are then implemented by it, by implementing the InterfaceType trait.
PluginAsyncRuntime_TO
The trait object for PluginAsyncRuntime.

Traits

PluginAsyncRuntime
Async runtime for performing asynchronous operations in the plugin. See [PluginTokioWrapper] on the host side for FFI-safe implementation.

Type Aliases

PluginAsyncRuntime_Backend
An alias for the underlying implementation of PluginAsyncRuntime_TO.
PluginAsyncRuntime_CTO
A type alias for the const-constructible PluginAsyncRuntime_TO.