Module ffi

Module ffi 

This module defines the FFI interface for the plugin system, including types and traits.

Structs

PluginChannel
PluginChannels
PluginCheckpointEpoch
PluginMetric_Interface
Describes the traits required when constructing a NonExhaustive<> from PluginMetric,by implementing InterfaceType.
PluginMetric_NEMarker
A marker type which implements StableAbi with the layout of PluginMetric,used as a phantom field of NonExhaustive.
PluginMetric_Storage
The default InlineStorage that NonExhaustive uses for PluginMetric.
PluginMetricsChannel
PluginMetricsRecorder
PluginMsg_Interface
Describes the traits required when constructing a NonExhaustive<> from PluginMsg,by implementing InterfaceType.
PluginMsg_NEMarker
A marker type which implements StableAbi with the layout of PluginMsg,used as a phantom field of NonExhaustive.
PluginMsg_Storage
The default InlineStorage that NonExhaustive uses for PluginMsg.
PluginOptions
SafeArrowArray
SafeArrowColumn
A single Arrow array (column) transported across the FFI boundary.
SafeArrowSchema
Custom wrapper for FFI_ArrowSchema DataFusion’s wrapper (WrappedSchema) looks almost the same, but since FFI_ArrowSchema doesn’t implement Sync, we need to add a mutex to allow concurrent access
SafeUdfArg
A UDF argument transported across the FFI boundary, preserving scalar vs array semantics.

Enums

PluginLogging
Logging configuration for the plugin.
PluginMetric
PluginMsg

Traits

PluginMetric_Bounds
An alias for the traits that NonExhaustive<PluginMetric,_,_> requires to be constructed,and implements afterwards.
PluginMsg_Bounds
An alias for the traits that NonExhaustive<PluginMsg,_,_> requires to be constructed,and implements afterwards.

Type Aliases

PluginMetric_NE
An alias for NonExhaustive wrapping a PluginMetric.
PluginMsg_NE
An alias for NonExhaustive wrapping a PluginMsg.