#[repr(C)]pub struct PluginChannel {
pub sender: RSender<PluginMsg_NE>,
pub receiver: RReceiver<PluginMsg_NE>,
}Fields
sender: RSender<PluginMsg_NE>receiver: RReceiver<PluginMsg_NE>Implementations
Sourceimpl PluginChannel
impl PluginChannel
pub fn new(channels: (RSender<PluginMsg_NE>, RReceiver<PluginMsg_NE>)) -> Self
pub async fn send_with_retry<CreatePayloadFn>(
&self,
runtime: &PluginAsyncRuntimeObj,
op_name: &str,
create_payload: CreatePayloadFn,
) -> Result<(), PluginError>where
CreatePayloadFn: Fn() -> PluginMsg_NE,
Sourcepub async fn send_with_retry_callback<CreatePayloadFn, OnRetryFn>(
&self,
runtime: &PluginAsyncRuntimeObj,
op_name: &str,
create_payload: CreatePayloadFn,
on_retry: Option<OnRetryFn>,
retry_delay: Duration,
) -> Result<(), PluginError>
pub async fn send_with_retry_callback<CreatePayloadFn, OnRetryFn>( &self, runtime: &PluginAsyncRuntimeObj, op_name: &str, create_payload: CreatePayloadFn, on_retry: Option<OnRetryFn>, retry_delay: Duration, ) -> Result<(), PluginError>
Send a message with retry logic if the channel is full. Uses try_send to avoid blocking the thread, and retries with a delay.
Arguments
runtime- The async runtime for sleeping between retriesop_name- Name used in error messages and loggingcreate_payload- The function to create the payload to send. This is called every send attempt.on_retry- Optional callback executed on each retry attempt. Return false to stop retrying.