This module defines the API that can be used for implementing plugins.
NOTE: this API is NOT FFI-safe and is intended for use in the plugin AFTER the FFI layer.
See plugin_interface::ffi for the FFI-safe types and traits.
Structs
- Checkpoint
Epoch - Plugin
State Backend - State backend for plugins.
- Plugin
State Backend Factory
Enums
Statics
Traits
- Preprocessor
Plugin - Optional, non-FFI trait for the plugins to implement preprocessor support. Preprocessors transform the raw topology config string before parsing.
- Side
Output Plugin - Trait for plugins to implement side output support.
Side outputs observe data from all sources without modifying the pipeline.
Unlike other plugin types, side outputs use direct FFI invocation (no channels).
One instance is created per source via
new(source_name, schema, options, metrics_recorder). - Sink
Plugin - Optional, non-FFI trait for the plugins to implement sink support.
- Source
Plugin - Optional, non-FFI trait for the plugins to implement source support.
- Supports
Graceful Shutdown - Transform
Plugin - Optional, non-FFI trait for the plugins to implement transform support.