pub trait PreprocessorPlugin: Send + Sync {
// Required method
fn preprocess_topology<'life0, 'async_trait>(
&'life0 self,
config: String,
) -> Pin<Box<dyn Future<Output = Result<String, PluginError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Optional, non-FFI trait for the plugins to implement preprocessor support. Preprocessors transform the raw topology config string before parsing.
Required Methods
fn preprocess_topology<'life0, 'async_trait>(
&'life0 self,
config: String,
) -> Pin<Box<dyn Future<Output = Result<String, PluginError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".