This module is generated by the #[sabi_trait] attribute on PluginAsyncRuntime
Structs
- Plugin
Async Runtime_ Interface - A marker type describing the traits that are required when constructing
PluginAsyncRuntime_TO,and are then implemented by it, by implementing theInterfaceTypetrait. - Plugin
Async Runtime_ TO - The trait object for PluginAsyncRuntime.
Traits
- Plugin
Async Runtime - Async runtime for performing asynchronous operations in the plugin.
See [
PluginTokioWrapper] on the host side for FFI-safe implementation.
Type Aliases
- Plugin
Async Runtime_ Backend - An alias for the underlying implementation of
PluginAsyncRuntime_TO. - Plugin
Async Runtime_ CTO - A type alias for the const-constructible
PluginAsyncRuntime_TO.